@@ -1,8 +1,8 @@
-/**
- * Starts Farabi... :)
- */
-function startFarabi(editorId) {
 
+// Start Farabi when the document loads
+$(function() {
+	var editorId = "editor";
+	
 	// Cache dialog jQuery references for later use
 	var $perl_critic_dialog = $('#perl-critic-dialog');
 	var $about_dialog = $('#about-dialog');
@@ -11,6 +11,7 @@ function startFarabi(editorId) {
 	var $openFileDialog    = $("#open-file-dialog");
 	var $actionsDialog    = $("#actions-dialog");
 	var $optionsDialog = $("#options-dialog");
+	var $perlDocDialog = $("#perl-doc-dialog");
 
 	$("#theme_selector").change(function() {
 		var $selectedTheme = $(":selected", this);
@@ -65,7 +66,6 @@ function startFarabi(editorId) {
 				$(".preview").html('<span class="text-error">No results found!</span>');
 			}
 			if(bShowDialog) {
-				$('a[href="#learn-tab"]').tab('show');
 				$(".topic").select().focus();
 			}
 		});
@@ -133,6 +133,9 @@ function startFarabi(editorId) {
 			"F1": function(cm) {
 				displayHelp(cm);
 			},
+			'Alt-A': function(cm) {
+				$(".actions-button").click();
+			}
 		}
 	});
 
@@ -202,7 +205,9 @@ function startFarabi(editorId) {
 				dataType: 'json',
 			});
 		}
-	})
+	}).change(function() {
+		console.error($(this).val());
+	});;
 	
 	$("#ok-button", $actionsDialog).click(function() {
 		$actionsDialog.modal('hide');
@@ -212,11 +217,80 @@ function startFarabi(editorId) {
 
 	$(".actions-button").click(function() {
 		$actionsDialog.modal('show');
-		$("#action-name").val('');
-		$("#action-name").focus();
+		$("#action").val('');
+		$("#action").focus();
 	});
 	
-	$(document).on('farabi-perl-tidy', function() {
+	var findAction = function() {
+		var action = $("#action", $actionsDialog).val();
+		$("#matched-actions", $actionsDialog).empty();
+		$("#ok-button", $actionsDialog).attr("disabled","disabled");
+		$.ajax({
+			type:    "POST",
+			url:     "/find-action",
+			data:    { "action": action },
+			success: function(matches) {
+				var html = '';
+				for(var i = 0; i < matches.length; i++) {
+					var a = matches[i];
+					html += '<li id="' + a.id + '"><a href="#">' + a.name +'</a></li>';
+				}
+				$("#ok-button", $actionsDialog).removeAttr("disabled");
+				$("#matched-actions", $actionsDialog).html(html);
+				$("#matched-actions li", $actionsDialog).click(function() {
+					$actionsDialog.modal('hide');
+					var actionId = $(this).attr('id');
+					$(document).trigger(actionId);
+				});
+			},
+			error:   function(jqXHR, textStatus, errorThrown) {
+				console.error("Error:\n" + textStatus + "\n" + errorThrown);
+			}
+		});
+	}
+
+	var findActionTimeoutId;
+	$("#action", $actionsDialog).on('input', function() {
+		clearTimeout(findActionTimeoutId);
+		findActionTimeoutId = setTimeout(findAction, 250);
+	});
+
+	$("#action", $actionsDialog).keyup(function(evt) {
+		var keyCode = evt.keyCode;
+		if(keyCode == 40) {
+			$("#matched-actions", $actionsDialog).focus();
+		} else if(keyCode == 13) {
+			var $okButton = $("#ok-button", $actionsDialog);
+			if(!$okButton.attr('disabled')) {
+				$okButton.click();
+			}
+		}
+	});
+
+	$("#ok-button", $openFileDialog).click(function() {
+		var filename = $("#search-results option:selected", $openFileDialog).attr('id');
+		if (!filename) {
+			console.warn("file name is empty");
+			return;
+		}
+		$.ajax({
+			url:     "/open_file",
+			data:    { "filename": filename },
+			success: function(code) {
+				editor.setValue(code);
+			},
+			error:   function(jqXHR, textStatus, errorThrown) {
+				console.error("Error!" + textStatus + ", " + errorThrown);
+			}
+		});
+	});
+
+	
+	$(document).on('action-perl-doc', function() {
+		$perlDocDialog.modal('show');
+	});
+
+	$(document).on('action-perl-tidy', function() {
 		$.post('/perl_tidy', {"source": editor.getValue()}, function(data) {
 			if(data.error == '') {
 				editor.setValue(data.source);
@@ -226,14 +300,14 @@ function startFarabi(editorId) {
 		});
 	});
 
-	$(document).on('farabi-open-file', function() {
+	$(document).on('action-open-file', function() {
 		$openFileDialog.modal('show');
 		$("#file", $openFileDialog).val('').focus();
 		$("#search-results", $openFileDialog).empty();
 		$("#ok-button", $openFileDialog).attr("disabled","disabled");
 	});
 
-	$(document).on('farabi-open-url', function() {
+	$(document).on('action-open-url', function() {
 		var url = prompt("Please Enter a http/https file location:" + 
 			"\ne.g https://raw.github.com/ihrd/uri/master/lib/URI.pm");
 		if(!url) {
@@ -248,20 +322,20 @@ function startFarabi(editorId) {
 		);
 	});
 
-	$(document).on('farabi-syntax-check', function() {
+	$(document).on('action-syntax-check', function() {
 		alert("TODO syntax check");
 	});
 
-	$(document).on('farabi-perl-critic', function() {
+	$(document).on('action-perl-critic', function() {
 		alert("TODO perl critic");
 	});
 
-	$(document).on('farabi-options', function() {
+	$(document).on('action-options', function() {
 		$optionsDialog.modal('show');
 		$("#mode_selector", $optionsDialog).focus();
 	});
 
-	$(document).on('farabi-run', function() {
+	$(document).on('action-run', function() {
 		// Run file
 		$runDialog.modal('show');
 		$("#runtime", $runDialog).focus().change();
@@ -372,9 +446,6 @@ function startFarabi(editorId) {
 		
 		// Handle STDOUT
 		$output.val($output.val() + data.stdout + "\nExit code: " + data.exit);
-		
-		// Show output tab
-		$('a[href="#output-tab"]').tab('show');
 	};
 
 	var perlCriticWidgets = [];
@@ -465,7 +536,7 @@ function startFarabi(editorId) {
 		});
 	};
 
-	$('.about_button').click(function() {
+	$(document).on('action-about', function() {
 		if(typeof p5pkg == 'undefined') {
 			$.ajax({
 				url: 'assets/perlito/perlito5.min.js',
@@ -485,7 +556,7 @@ function startFarabi(editorId) {
 		$about_dialog.modal("show");
 	});
 
-	$('.help_button').click(function() {
+	$(document).on('action-help', function() {
 		$help_dialog.modal("show");
 	});
 
@@ -538,9 +609,9 @@ function startFarabi(editorId) {
 			$(this).parent().parent().addClass("error");
 		}
 	});
-}
+});
 
-function runOnPerlito5(source) {
+var runOnPerlito5 = function(source) {
 
 	var $output = $('#output');
 
@@ -599,9 +670,9 @@ function runOnPerlito5(source) {
 	// Show output tab
 	$('a[href="#output-tab"]').tab('show');
 
-}
+};
 
-function runOnPerlito6(source) {
+var runOnPerlito6 = function(source) {
 	var $output = $('#output');
 	window.print = function(s) {
 		$output.val($output.val() + s + "\n");
@@ -624,9 +695,4 @@ function runOnPerlito6(source) {
 
         // Show output tab
         $('a[href="#output-tab"]').tab('show');
-}
-
-// Start Farabi when the document loads
-$(function() {
-	startFarabi("editor");
-});
+};
\ No newline at end of file
